==> haskell-memotrie-0.6.10-220-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 MemoTrie
version:              0.6.10
visibility:           public
id:                   MemoTrie-0.6.10-83ph265d8GcLx6I2AIzUEy
key:                  MemoTrie-0.6.10-83ph265d8GcLx6I2AIzUEy
license:              BSD-3-Clause
copyright:            (c) 2008-2019 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
homepage:             https://github.com/conal/MemoTrie
synopsis:             Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.

    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>

    &#199; 2008-2019 by Conal Elliott; BSD3 license.

category:             Data
abi:                  b2e42a397570fba97b8192d7fdeb019f
exposed:              True
exposed-modules:      Data.MemoTrie
import-dirs:          /usr/lib/ghc-9.2.8/site-local/MemoTrie-0.6.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/MemoTrie-0.6.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-memotrie
hs-libraries:         HSMemoTrie-0.6.10-83ph265d8GcLx6I2AIzUEy
depends:
    base-4.16.4.0 newtype-generics-0.6.2-JT4UWX6eaX3CHrPrVbp5oj

haddock-interfaces:   /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html:         /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-memotrie-0.6.11-29.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MemoTrie
version:              0.6.11
visibility:           public
id:                   MemoTrie-0.6.11-CZlZiu1VJ6jByImjJrWSzb
key:                  MemoTrie-0.6.11-CZlZiu1VJ6jByImjJrWSzb
license:              BSD-3-Clause
copyright:            (c) 2008-2019 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
homepage:             https://github.com/conal/MemoTrie
synopsis:             Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.

    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>

    &#199; 2008-2019 by Conal Elliott; BSD3 license.

category:             Data
abi:                  a268217f99199afc6e1a7cdacfc5a1ff
exposed:              True
exposed-modules:      Data.MemoTrie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/MemoTrie-0.6.11
library-dirs:         /usr/lib/ghc-9.4.8/site-local/MemoTrie-0.6.11
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/MemoTrie-0.6.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-memotrie
hs-libraries:         HSMemoTrie-0.6.11-CZlZiu1VJ6jByImjJrWSzb
depends:
    base-4.17.2.1 newtype-generics-0.6.2-BbNhKbOTCyp6U0BaYPY4Pz

haddock-interfaces:   /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html:         /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
